@@ -26,6 +26,18 @@
 #include <config.h>
 #endif
 
+#include <kdeversion.h>
+
+#ifdef KDE_IS_VERSION
+#if KDE_IS_VERSION( 3, 1, 90 )
+#undef KIG_DONT_USE_NEW_KMAINWINDOW_FEATURES
+#else
+#define KIG_DONT_USE_NEW_KMAINWINDOW_FEATURES
+#endif
+#else
+#define KIG_DONT_USE_NEW_KMAINWINDOW_FEATURES
+#endif
+
 #include <kapplication.h>
 #include <kparts/mainwindow.h>
 #include <dcopclient.h>
@@ -109,8 +121,11 @@ class Kig : public KParts::MainWindow
  private slots:
   void fileNew();
   void fileOpen();
+  // Qt moc doesn't handle ifdef's, so i'm disabling it..
+// #ifdef KIG_DONT_USE_NEW_KMAINWINDOW_FEATURES
   void optionsShowToolbar();
   void optionsShowStatusbar();
+// #endif
   void optionsConfigureKeys();
   void optionsConfigureToolbars();
 
@@ -121,8 +136,10 @@ class Kig : public KParts::MainWindow
 
   KParts::ReadWritePart *m_part;
 
+//#ifdef KIG_DONT_USE_NEW_KMAINWINDOW_FEATURES
   KToggleAction *m_toolbarAction;
   KToggleAction *m_statusbarAction;
+//#endif
   KRecentFilesAction *m_recentFilesAction;
 
   static bool kimageioRegistered;
