@@ -26,23 +26,25 @@
 #include <qptrlist.h>
 
 #include "../misc/objects.h"
-#include "../misc/rect.h"
 
-class QWidget;
-class KURL;
+class KAboutData;
 class KActionMenu;
 class KCommandHistory;
-class KAboutData;
+class KPrinter;
 class KToolBar;
+class KURL;
+class QWidget;
 
+class Coordinate;
+class CoordinateSystem;
+class GUIAction;
+class KigGUIAction;
 class KigMode;
 class KigObjectsPopup;
-class CoordinateSystem;
-class MacroWizardImpl;
 class KigView;
+class MacroWizardImpl;
 class Object;
-class KigGUIAction;
-class GUIAction;
+class Rect;
 class ScreenInfo;
 
 /**
@@ -96,6 +98,9 @@ public slots:
   void fileSaveAs();
   void fileSave();
 
+  void filePrint();
+  void filePrintPreview();
+
   void unplugActionLists();
   void plugActionLists();
 
@@ -196,13 +201,12 @@ public:
   QPtrList<KAction> aMNewAll;
   QPtrList<KAction> aMNewConic;
 
+
   KAction* aCancelConstruction;
   KAction* aDeleteObjects;
   KAction* aNewMacro;
   KAction* aShowHidden;
   KAction* aConfigureTypes;
-  KAction* aFullScreen;
-  KAction* aFixedPoint;
   myvector<KigGUIAction*> aActions;
 
   /**
@@ -225,6 +229,8 @@ public:
   void enableConstructActions( bool enabled );
 
 protected:
+  void doPrint( KPrinter& printer );
+
   std::vector<KigWidget*> mwidgets;
 
   KigView* m_widget;
