@@ -68,17 +68,7 @@ class KigWidget : public QWidget
   // always want circles to look like circles etc...
   Rect matchScreenShape( const Rect& r ) const;
 
-  // to avoid stupid syntax.  Actually, the KigMode's implement
-  // functionality which is logically inherent to KigView.. So this
-  // isn't just an ugly hack ;)
-  friend class KigMode;
-  friend class NormalMode;
-  friend class MovingModeBase;
-  friend class ConstructMode;
-  friend class PointConstructMode;
-  friend class DefineMacroMode;
-  friend class DragRectMode;
-
+public:
   // what do the still objects look like
   // wondering if this is appropriate, maybe it should be part of
   // MovingMode ?
@@ -86,6 +76,8 @@ class KigWidget : public QWidget
   // temporary, gets bitBlt'd (copied) onto the widget
   // (to avoid flickering)
   QPixmap curPix;
+
+protected:
   std::vector<QRect> oldOverlay;
 
   /**
@@ -94,14 +86,35 @@ class KigWidget : public QWidget
    */
   ScreenInfo msi;
 
+  /**
+   * is this a full-screen widget ?
+   */
+  bool misfullscreen;
+
 public:
+  /**
+   * standard qwidget constructor.  if fullscreen is true, we're a
+   * fullscreen widget.
+   */
   KigWidget( KigDocument* doc,
              KigView* view,
              QWidget* parent = 0,
-             const char* name = 0
+             const char* name = 0,
+             bool fullscreen = false
 	   );
   ~KigWidget();
 
+  bool isFullScreen() const;
+  void setFullScreen( bool f );
+
+  const KigView* view() const {
+    return mview;
+  };
+
+  KigView* view() {
+    return mview;
+  };
+
   /**
    * The following are functions used by KigMode's to tell us to draw
    * stuff...
@@ -145,7 +158,8 @@ public:
    * related to this system.
    * These are mapped by the KigView using the ScreenInfo class.
    */
-  const Rect showingRect();
+  const Rect showingRect() const;
+  void setShowingRect( const Rect& r );
 
   const Coordinate fromScreen( const QPoint& p );
   const Rect fromScreen( const QRect& r );
@@ -165,13 +179,14 @@ public:
 
   const KigDocument& document() const;
 
-public slots:
+public:
   // this is connected to KigDocument::recenterScreen, check that signal
   // out for an explanation...
   void recenterScreen();
   // ...
   void zoomIn();
   void zoomOut();
+  void zoomRect();
 
   void redrawScreen( bool paintOnWidget = true );
 };
@@ -187,11 +202,6 @@ class KigView
 {
   Q_OBJECT
 
-  KAction* aZoomIn;
-  KAction* aZoomOut;
-  KAction* aCenterScreen;
-  KAction* aExportToImage;
-
   QGridLayout* mlayout;
   QScrollBar* mrightscroll;
   QScrollBar* mbottomscroll;
@@ -205,6 +215,7 @@ class KigView
 
 public:
   KigView( KigDocument* inDoc,
+           bool fullscreen = false,
 	   QWidget* parent = 0,
 	   const char* name = 0
 	   );
@@ -219,10 +230,14 @@ public:
 
 public slots:
   void updateScrollBars();
+  void zoomIn();
+  void zoomOut();
+  void zoomRect();
+  void recenterScreen();
+  void toggleFullScreen();
 
 private slots:
   void slotRightScrollValueChanged( int );
   void slotBottomScrollValueChanged( int );
-  void slotExportToImage();
 };
 #endif
