@@ -20,6 +20,7 @@
 
 #include "objects.h"
 #include "../objects/object.h"
+#include "../kig/kig_part.h"
 
 // these first two functions were written before i read stuff about
 // graph theory and algorithms, so i'm sure they're far from optimal.
@@ -163,3 +164,60 @@ Objects getAllParents( const Objects& objs )
   };
   return ret;
 };
+
+// this calls delChild() on all of o's parents..
+void delChildFromParents( Object* o )
+{
+  Objects parents = o->parents();
+  for ( Objects::iterator i = parents.begin(); i != parents.end(); ++i )
+    (*i)->delChild( o );
+};
+
+void addChildToParents( Object* o )
+{
+  Objects parents = o->parents();
+  for ( Objects::iterator i = parents.begin(); i != parents.end(); ++i )
+    (*i)->addChild( o );
+};
+
+Objects deadParents( Objects& os )
+{
+  // what we do here is simulate deleting the children ( by calling
+  // delChild on their parents ), and then see if the parents have
+  // children left.. if they don't, we simulate deleting them too and
+  // continue with their parents..
+
+  Objects todo;
+  for ( Objects::iterator i = os.begin(); i != os.end(); ++i )
+  {
+    todo |= (*i)->parents();
+    delChildFromParents( *i );
+  };
+
+  // these are the objects that we delChild'ed from their parents, and
+  // which we need to readd later..
+  Objects readd = os;
+
+  Objects ret;
+
+  while ( ! todo.empty() )
+  {
+    Objects newtodo;
+    for ( Objects::iterator i = todo.begin(); i != todo.end(); ++i )
+    {
+      if ( (*i)->isInternal() && (*i)->children().empty() )
+      {
+        ret.push_back( *i );
+        delChildFromParents( *i );
+        readd.push_back( *i );
+        newtodo |= (*i)->parents();
+      };
+    };
+    todo = newtodo;
+  };
+
+  for ( Objects::iterator i = readd.begin(); i != readd.end(); ++i )
+    addChildToParents( *i );
+
+  return ret;
+};
