@@ -16,8 +16,8 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 // 02111-1307, USA.
 
-#ifndef CALCPATHS_H
-#define CALCPATHS_H
+#ifndef KIG_MISC_CALCPATHS_H
+#define KIG_MISC_CALCPATHS_H
 
 #include "objects.h"
 
@@ -57,4 +57,19 @@ Objects sideOfTreePath( const Objects& from, const Object* to );
  */
 Objects getAllParents( const Objects& objs );
 
+/**
+ * this function returns all the objects that are parents of an
+ * object in os, that are dead.  This means that they are internal (
+ * see Object::isInternal() ), and that they have no other children
+ * than objects that are in os, or other dead parents..
+ * It is used by functions that need to delete certain objects, to
+ * find out what objects can be deleted along..
+ */
+Objects deadParents( Objects& os );
+
+// this calls delChild() on all of o's parents..
+void delChildFromParents( Object* o );
+// reverses delChildFromParents..
+void addChildToParents( Object* o );
+
 #endif
