@@ -426,7 +426,8 @@ const Coordinate calcCenter(
     // which means they're the same line..
     // FIXME: i would normally throw an error here, but KDE doesn't
     // use exceptions, so i'm returning a bogus point :(
-    return (a+c)/2;
+    return a.invalidCoord();
+    /* return (a+c)/2; */
   };
   double denominator = 0.5 / numerator;
 
@@ -470,3 +471,11 @@ bool lineInRect( const Rect& r, const Coordinate& a, const Coordinate& b,
     ( imp->contains( bottomint, width, w ) && r.contains( bottomint, miss ) ) ||
     ( imp->contains( topint, width, w ) && r.contains( topint, miss ) );
 };
+
+bool operator==( const LineData& l, const LineData& r )
+{
+  return l.a == r.a && l.b == r.b;
+};
+
+const double double_inf = HUGE_VAL;
+
