@@ -45,6 +45,8 @@
 class ObjectImp;
 class KigWidget;
 
+extern const double double_inf;
+
 /**
  * Here, we define some algorithms which we need in
  * various places...
@@ -64,6 +66,8 @@ public:
   LineData( const Coordinate& na, const Coordinate& nb ) : a( na ), b( nb ) {};
 };
 
+bool operator==( const LineData& l, const LineData& r );
+
 /**
  * This calcs the rotation of point a around point c by arc arc.  Arc
  * is in radians, in the range 0 < arc < 2*pi ...
