@@ -799,6 +799,7 @@ void KigPainter::drawVector( const Coordinate& a, const Coordinate& b )
   drawSegment( b, d );
 }
 
+/* *** this function is commented out ***
 inline Coordinate locusGetCoord( double p, const CurveImp* curve, const ObjectHierarchy& h,
                                  bool& valid, const KigDocument& doc )
 {
@@ -821,13 +822,10 @@ inline Coordinate locusGetCoord( double p, const CurveImp* curve, const ObjectHi
   delete o;
   return ret;
 };
+ */
 
-void KigPainter::drawLocus( const CurveImp* curve, const ObjectHierarchy& hier )
+void KigPainter::drawCurve( const CurveImp* curve )
 {
-  /// this function is based on drawConic, and its code comes mostly
-  /// from there too..  ( drawConic was based on an old version of
-  /// drawLocus, actually, but that's ancient history by now :) )
-
   // we manage our own overlay
   bool tNeedOverlay = mNeedOverlay;
   mNeedOverlay = false;
@@ -865,9 +863,14 @@ void KigPainter::drawLocus( const CurveImp* curve, const ObjectHierarchy& hier )
   // by forcing subdivision till h < hmax (with more or less the same
   // final result).
   // First push the [0,1] interval into the stack:
+
+  Coordinate coo1 = curve->getPoint( 0, valid, mdoc );
+  if ( ! valid ) coo1 = coo1.invalidCoord();
+  Coordinate coo2 = curve->getPoint( 1, valid, mdoc );
+  if ( ! valid ) coo2 = coo2.invalidCoord();
   workstack.push( workitem(
-                    coordparampair( 0, locusGetCoord( 0, curve, hier, valid, mdoc ) ), ///
-                    coordparampair( 1, locusGetCoord( 0, curve, hier, valid, mdoc ) ), ///
+                    coordparampair( 0, coo1 ),
+                    coordparampair( 1, coo2 ),
                     0 ) );
 
   // maxlength is the square of the maximum size that we allow
@@ -877,10 +880,10 @@ void KigPainter::drawLocus( const CurveImp* curve, const ObjectHierarchy& hier )
   // error squared is required to be less that sigma (half pixel)
   double sigma = maxlength/4;
   // distance between two parameter values cannot be too small
-  double hmin = 1e-4;
+  double hmin = 3e-5;
   // distance between two parameter values cannot be too large
-  double hmax = M_PI/20; ///
-  double hmaxoverlay = M_PI/4; ///
+  double hmax = 1.0/40;
+  double hmaxoverlay = 1.0/8;
 
   int count = 1;               // the number of segments we've already
                                // visited...
@@ -897,23 +900,46 @@ void KigPainter::drawLocus( const CurveImp* curve, const ObjectHierarchy& hier )
     bool curitemok = true;
     while ( curitemok && count++ < maxnumberofpoints )
     {
-      // we take the middle parameter of the two previous points...
+      double t0 = curitem.first.first;
+      double t1 = curitem.second.first;
       Coordinate p0 = curitem.first.second;
+      bool valid0 = true;
+      if ( ! p0.valid() ) valid0 = false;
       Coordinate p1 = curitem.second.second;
-      double t2 = ( curitem.first.first + curitem.second.first ) / 2;
-      double h = fabs( curitem.second.first - curitem.first.first ) /2;
-      Rect *overlaypt = curitem.overlay;
-      Coordinate p2 = locusGetCoord( t2, curve, hier, valid, mdoc ); ///
+      bool valid1 = true;
+      if ( ! p1.valid() ) valid1 = false;
 
-      bool dooverlay = ! overlaypt && h < hmaxoverlay
+      // we take the middle parameter of the two previous points...
+      double t2 = ( t0 + t1 ) / 2;
+      double h = fabs( t1 - t0 ) /2;
+
+      // if exactly one of the two endpoints is invalid, then
+      // we prefer to find an internal value of the parameter
+      // separating valid points from invalid points.  We use
+      // a bisection strategy (this is not implemented yet!)
+//      if ( ( valid0 && ! valid1 ) || ( valid1 && ! valid0 ) )
+//      {
+//	while ( h >= hmin )
+//	{
+//	  .......................................
+//	}
+//      }
+
+      Rect *overlaypt = curitem.overlay;
+      Coordinate p2 = curve->getPoint( t2, valid, mdoc );
+      if ( ! valid ) p2 = p2.invalidCoord();
+      bool allvalid = valid && valid0 && valid1;
+      bool dooverlay = ! overlaypt && h < hmaxoverlay && valid0 && valid1
  && fabs( p0.x - p1.x ) <= overlayRectSize()
  && fabs( p0.y - p1.y ) <= overlayRectSize();
-      bool addn = valid && sr.contains( p2 ); ///
+      bool addn = valid && sr.contains( p2 );
       // estimated error between the curve and the segments
-      double errsq = (0.5*p0 + 0.5*p1 - p2).squareLength();
+      double errsq = 1e21;
+      if ( allvalid ) errsq = (0.5*p0 + 0.5*p1 - p2).squareLength();
       errsq /= 4;
       curitemok = false;
-      bool dodraw = valid && h < hmax && ( errsq < sigma || h < hmin ); ///
+//      bool dodraw = allvalid && h < hmax && ( errsq < sigma || h < hmin );
+      bool dodraw = allvalid && h < hmax && errsq < sigma;
       if ( tNeedOverlay && ( dooverlay || dodraw ) )
       {
         Rect newoverlay( p0, p1 );
@@ -930,13 +956,13 @@ void KigPainter::drawLocus( const CurveImp* curve, const ObjectHierarchy& hier )
         mP.drawLine( tp0, tp2 );
         mP.drawLine( tp2, tp1 );
       }
-      else if ( valid ) ///
+      else if ( h >= hmin )   // we do not continue to subdivide indefinitely!
       {
         // push into stack in order to process both subintervals
-        if (addn || sr.contains( p0 ) || h >= hmax)
+        if ( addn || ( valid0 && sr.contains( p0 ) ) || h >= hmax )
           workstack.push( workitem( curitem.first, coordparampair( t2, p2 ),
                                     overlaypt ) );
-        if (addn || sr.contains( p1 ) || h >= hmax)
+        if ( addn || ( valid1 && sr.contains( p1 ) ) || h >= hmax )
         {
           curitem = workitem( coordparampair( t2, p2 ), curitem.second ,
                               overlaypt );
@@ -946,6 +972,12 @@ void KigPainter::drawLocus( const CurveImp* curve, const ObjectHierarchy& hier )
     }
   }
 
+  if ( ! workstack.empty () )
+  {
+    kdDebug() << "Stack not empty in drawLocus!\n" << endl;
+    while ( ! workstack.empty () ) workstack.pop ();
+  }
+  assert ( workstack.empty() );
   assert ( tNeedOverlay || overlaystack.empty() );
   if ( tNeedOverlay )
   {
@@ -984,7 +1016,7 @@ void KigPainter::drawTextFrame( const Rect& frame,
   };
   setPen( oldpen );
   setBrush( oldbrush );
-  drawText( frame, s, Qt::AlignVCenter | Qt::AlignHCenter );
+  drawText( frame, s, Qt::AlignVCenter | Qt::AlignLeft );
 }
 
 void KigPainter::drawArc( const Coordinate& center, const double radius,
