@@ -49,6 +49,7 @@ public:
   const QCStringList properties() const;
   const QCStringList propertiesInternalNames() const;
   ObjectImp* property( uint which, const KigDocument& w ) const;
+  const char* iconForProperty( uint which ) const;
   int impRequirementForProperty( uint which ) const;
 
   int id() const;
@@ -74,6 +75,8 @@ public:
 
   QString cartesianEquationString( const KigDocument& w ) const;
   QString polarEquationString( const KigDocument& w ) const;
+
+  bool equals( const ObjectImp& rhs ) const;
 };
 
 #endif
