@@ -99,7 +99,7 @@ ObjectImp* CircleBTPType::calc( const Args& targs, const KigDocument& ) const
 
       // length:
       // sqrt( 3 ) == tan( 60 ) == sqrt( 2^2 - 1^2 )
-      double l = sqrt(3) * (a-b).length() / 2;
+      double l = 1.73205080756 * (a-b).length() / 2;
 
       double d2 = d*d;
       double l2 = l*l;
@@ -118,7 +118,9 @@ ObjectImp* CircleBTPType::calc( const Args& targs, const KigDocument& ) const
   };
 
   const Coordinate center = calcCenter( a, b, c );
-  return new CircleImp( center, (center - a ).length() );
+  if ( center.valid() )
+    return new CircleImp( center, (center - a ).length() );
+  else return new InvalidImp;
 }
 
 int CircleBCPType::resultId() const
@@ -131,14 +133,14 @@ int CircleBTPType::resultId() const
   return ObjectImp::ID_CircleImp;
 }
 
-static const ArgParser::spec argsspecpd[] =
+static const ArgParser::spec argsspecCircleBPR[] =
 {
   { ObjectImp::ID_PointImp, I18N_NOOP( "Construct a circle with this center" ) },
   { ObjectImp::ID_DoubleImp, "UNUSED" }
 };
 
 CircleBPRType::CircleBPRType()
-  : ArgparserObjectType( "CircleBPR", argsspecpd, 2 )
+  : ArgparserObjectType( "CircleBPR", argsspecCircleBPR, 2 )
 {
 }
 
