@@ -19,6 +19,7 @@
 #include "line_imp.h"
 
 #include "bogus_imp.h"
+#include "point_imp.h"
 
 #include "../misc/rect.h"
 #include "../misc/common.h"
@@ -56,6 +57,18 @@ int AbstractLineImp::impRequirementForProperty( uint which ) const
   else return ID_LineImp;
 }
 
+const char* AbstractLineImp::iconForProperty( uint which ) const
+{
+  if ( which < Parent::numberOfProperties() )
+    return Parent::iconForProperty( which );
+  if ( which == Parent::numberOfProperties() )
+    return "slope"; // slope
+  if ( which == Parent::numberOfProperties() + 1 )
+    return "text"; // equation
+  else assert( false );
+  return "";
+}
+
 ObjectImp* AbstractLineImp::property( uint which, const KigDocument& w ) const
 {
   if ( which < Parent::numberOfProperties() )
@@ -65,6 +78,7 @@ ObjectImp* AbstractLineImp::property( uint which, const KigDocument& w ) const
   if ( which == Parent::numberOfProperties() + 1 )
     return new StringImp( equationString() );
   else assert( false );
+  return new InvalidImp;
 }
 
 const QCStringList AbstractLineImp::propertiesInternalNames() const
@@ -102,13 +116,14 @@ int LineImp::type() const
 
 const uint SegmentImp::numberOfProperties() const
 {
-  return Parent::numberOfProperties() + 1;
+  return Parent::numberOfProperties() + 2;
 }
 
 const QCStringList SegmentImp::propertiesInternalNames() const
 {
   QCStringList s = Parent::propertiesInternalNames();
   s << I18N_NOOP( "length" );
+  s << I18N_NOOP( "mid-point" );
   assert( s.size() == SegmentImp::numberOfProperties() );
   return s;
 }
@@ -117,6 +132,7 @@ const QCStringList SegmentImp::properties() const
 {
   QCStringList s = Parent::properties();
   s << I18N_NOOP( "Length" );
+  s << I18N_NOOP( "Mid Point" );
   assert( s.size() == SegmentImp::numberOfProperties() );
   return s;
 }
@@ -128,13 +144,28 @@ int SegmentImp::impRequirementForProperty( uint which ) const
   else return ID_SegmentImp;
 }
 
+const char* SegmentImp::iconForProperty( uint which ) const
+{
+  if ( which < Parent::numberOfProperties() )
+    return Parent::iconForProperty( which );
+  else if ( which == Parent::numberOfProperties() )
+    return "distance"; // length
+  else if ( which == Parent::numberOfProperties() + 1 )
+    return "bisection"; // mid point
+  else assert( false );
+  return "";
+}
+
 ObjectImp* SegmentImp::property( uint which, const KigDocument& w ) const
 {
   if ( which < Parent::numberOfProperties() )
     return Parent::property( which, w );
-  if ( which == Parent::numberOfProperties() )
+  else if ( which == Parent::numberOfProperties() )
     return new DoubleImp( mdata.dir().length() );
+  else if ( which == Parent::numberOfProperties() + 1 )
+    return new PointImp( ( mdata.a + mdata.b ) / 2 );
   else assert( false );
+  return new InvalidImp;
 }
 
 double AbstractLineImp::slope() const
@@ -145,15 +176,18 @@ double AbstractLineImp::slope() const
 
 const QString AbstractLineImp::equationString() const
 {
-  QString ret = QString::fromUtf8( "y = %1x + %2" );
   Coordinate p = mdata.a;
   Coordinate q = mdata.b;
 
   double m = ( q.y - p.y ) / ( q.x - p.x );
-  double r = ( q.y - p.y ) * p.x / ( q.x - p.x ) + p.y;
+  double r = - ( q.y - p.y ) * p.x / ( q.x - p.x ) + p.y;
+
+  QString ret = QString::fromUtf8( "y = %1x " ) +
+                QString::fromUtf8( r > 0 ? "+" : "-" ) +
+                QString::fromUtf8( " %2" );
 
   ret = ret.arg( m, 0, 'g', 3 );
-  ret = ret.arg( r, 0, 'g', 3 );
+  ret = ret.arg( abs( r ), 0, 'g', 3 );
 
   return ret;
 }
@@ -427,4 +461,9 @@ void LineImp::visit( ObjectImpVisitor* vtor ) const
   vtor->visit( this );
 }
 
-
+bool AbstractLineImp::equals( const ObjectImp& rhs ) const
+{
+  return rhs.inherits( ID_LineImp ) &&
+    static_cast<const AbstractLineImp&>( rhs ).data() == data() &&
+    static_cast<const AbstractLineImp&>( rhs ).type() == type();
+}
